=============
Django Robots
=============

.. image:: https://jazzband.co/static/img/badge.svg
   :target: https://jazzband.co/
   :alt: Jazzband

This is a basic Django application to manage robots.txt files following the
`robots exclusion protocol`_, complementing the Django_ `Sitemap contrib app`_.

For installation instructions, see the documentation `install section`_;
for instructions on how to use this application, and on
what it provides, see the file "overview.txt" in the "docs/"
directory or on ReadTheDocs: http://django-robots.readthedocs.org/


Supported Django versions
-------------------------

* Django 1.6
* Django 1.7
* Django 1.8
* Django 1.9

Supported Python version
------------------------

* Python 2.6, 2.7
* Python 3.3, 3.4, 3.5


.. _install section: http://django-robots.readthedocs.org/en/latest/#installation
.. _robots exclusion protocol: http://en.wikipedia.org/wiki/Robots_exclusion_standard
.. _Django: http://www.djangoproject.com/
.. _Sitemap contrib app: http://docs.djangoproject.com/en/dev/ref/contrib/sitemaps/
